@@ -2,7 +2,7 @@ use crate::algorithm::{
     bounding_rect::BoundingRect, dimensions::HasDimensions, intersects::Intersects,
 };
 use crate::{
-    Coordinate, GeoNum, Geometry, GeometryCollection, GeometryCow, Line, LineString,
+    coord, Coordinate, GeoNum, Geometry, GeometryCollection, GeometryCow, Line, LineString,
     MultiLineString, MultiPoint, MultiPolygon, Point, Polygon, Rect, Triangle,
 };
 
@@ -19,18 +19,18 @@ pub enum CoordPos {
 /// # Examples
 ///
 /// ```rust
-/// use geo::{polygon, Coordinate};
+/// use geo::{polygon, coord};
 /// use geo::coordinate_position::{CoordinatePosition, CoordPos};
 ///
 /// let square_poly = polygon![(x: 0.0, y: 0.0), (x: 2.0, y: 0.0), (x: 2.0, y: 2.0), (x: 0.0, y: 2.0), (x: 0.0, y: 0.0)];
 ///
-/// let inside_coord = Coordinate { x: 1.0, y: 1.0 };
+/// let inside_coord = coord! { x: 1.0, y: 1.0 };
 /// assert_eq!(square_poly.coordinate_position(&inside_coord), CoordPos::Inside);
 ///
-/// let boundary_coord = Coordinate { x: 0.0, y: 1.0 };
+/// let boundary_coord = coord! { x: 0.0, y: 1.0 };
 /// assert_eq!(square_poly.coordinate_position(&boundary_coord), CoordPos::OnBoundary);
 ///
-/// let outside_coord = Coordinate { x: 5.0, y: 5.0 };
+/// let outside_coord = coord! { x: 5.0, y: 5.0 };
 /// assert_eq!(square_poly.coordinate_position(&outside_coord), CoordPos::Outside);
 /// ```
 pub trait CoordinatePosition {
@@ -421,7 +421,7 @@ where
         // coordinate of the current segment.
         let ray = Line::new(
             coord,
-            Coordinate {
+            coord! {
                 x: max_x,
                 y: coord.y,
             },
@@ -444,7 +444,7 @@ mod test {
 
     #[test]
     fn test_empty_poly() {
-        let square_poly: Polygon<f64> = Polygon::new(LineString(vec![]), vec![]);
+        let square_poly: Polygon<f64> = Polygon::new(LineString::new(vec![]), vec![]);
         assert_eq!(
             square_poly.coordinate_position(&Coordinate::zero()),
             CoordPos::Outside
@@ -455,25 +455,25 @@ mod test {
     fn test_simple_poly() {
         let square_poly = polygon![(x: 0.0, y: 0.0), (x: 2.0, y: 0.0), (x: 2.0, y: 2.0), (x: 0.0, y: 2.0), (x: 0.0, y: 0.0)];
 
-        let inside_coord = Coordinate { x: 1.0, y: 1.0 };
+        let inside_coord = coord! { x: 1.0, y: 1.0 };
         assert_eq!(
             square_poly.coordinate_position(&inside_coord),
             CoordPos::Inside
         );
 
-        let vertex_coord = Coordinate { x: 0.0, y: 0.0 };
+        let vertex_coord = coord! { x: 0.0, y: 0.0 };
         assert_eq!(
             square_poly.coordinate_position(&vertex_coord),
             CoordPos::OnBoundary
         );
 
-        let boundary_coord = Coordinate { x: 0.0, y: 1.0 };
+        let boundary_coord = coord! { x: 0.0, y: 1.0 };
         assert_eq!(
             square_poly.coordinate_position(&boundary_coord),
             CoordPos::OnBoundary
         );
 
-        let outside_coord = Coordinate { x: 5.0, y: 5.0 };
+        let outside_coord = coord! { x: 5.0, y: 5.0 };
         assert_eq!(
             square_poly.coordinate_position(&outside_coord),
             CoordPos::Outside
@@ -501,25 +501,25 @@ mod test {
             ],
         ];
 
-        let inside_hole = Coordinate { x: 14.0, y: 14.0 };
+        let inside_hole = coord! { x: 14.0, y: 14.0 };
         assert_eq!(poly.coordinate_position(&inside_hole), CoordPos::Outside);
 
-        let outside_poly = Coordinate { x: 30.0, y: 30.0 };
+        let outside_poly = coord! { x: 30.0, y: 30.0 };
         assert_eq!(poly.coordinate_position(&outside_poly), CoordPos::Outside);
 
-        let on_outside_border = Coordinate { x: 20.0, y: 15.0 };
+        let on_outside_border = coord! { x: 20.0, y: 15.0 };
         assert_eq!(
             poly.coordinate_position(&on_outside_border),
             CoordPos::OnBoundary
         );
 
-        let on_inside_border = Coordinate { x: 13.0, y: 15.0 };
+        let on_inside_border = coord! { x: 13.0, y: 15.0 };
         assert_eq!(
             poly.coordinate_position(&on_inside_border),
             CoordPos::OnBoundary
         );
 
-        let inside_coord = Coordinate { x: 12.0, y: 12.0 };
+        let inside_coord = coord! { x: 12.0, y: 12.0 };
         assert_eq!(poly.coordinate_position(&inside_coord), CoordPos::Inside);
     }
 
@@ -528,16 +528,16 @@ mod test {
         use crate::point;
         let line = Line::new(point![x: 0.0, y: 0.0], point![x: 10.0, y: 10.0]);
 
-        let start = Coordinate { x: 0.0, y: 0.0 };
+        let start = coord! { x: 0.0, y: 0.0 };
         assert_eq!(line.coordinate_position(&start), CoordPos::OnBoundary);
 
-        let end = Coordinate { x: 10.0, y: 10.0 };
+        let end = coord! { x: 10.0, y: 10.0 };
         assert_eq!(line.coordinate_position(&end), CoordPos::OnBoundary);
 
-        let interior = Coordinate { x: 5.0, y: 5.0 };
+        let interior = coord! { x: 5.0, y: 5.0 };
         assert_eq!(line.coordinate_position(&interior), CoordPos::Inside);
 
-        let outside = Coordinate { x: 6.0, y: 5.0 };
+        let outside = coord! { x: 6.0, y: 5.0 };
         assert_eq!(line.coordinate_position(&outside), CoordPos::Outside);
     }
 
@@ -545,10 +545,10 @@ mod test {
     fn test_degenerate_line() {
         let line = Line::new(point![x: 0.0, y: 0.0], point![x: 0.0, y: 0.0]);
 
-        let start = Coordinate { x: 0.0, y: 0.0 };
+        let start = coord! { x: 0.0, y: 0.0 };
         assert_eq!(line.coordinate_position(&start), CoordPos::Inside);
 
-        let outside = Coordinate { x: 10.0, y: 10.0 };
+        let outside = coord! { x: 10.0, y: 10.0 };
         assert_eq!(line.coordinate_position(&outside), CoordPos::Outside);
     }
 
@@ -556,8 +556,8 @@ mod test {
     fn test_point() {
         let p1 = point![x: 2.0, y: 0.0];
 
-        let c1 = Coordinate { x: 2.0, y: 0.0 };
-        let c2 = Coordinate { x: 3.0, y: 3.0 };
+        let c1 = coord! { x: 2.0, y: 0.0 };
+        let c2 = coord! { x: 3.0, y: 3.0 };
 
         assert_eq!(p1.coordinate_position(&c1), CoordPos::Inside);
         assert_eq!(p1.coordinate_position(&c2), CoordPos::Outside);
@@ -577,16 +577,16 @@ mod test {
             CoordPos::OnBoundary
         );
 
-        let midpoint = Coordinate { x: 0.5, y: 0.5 };
+        let midpoint = coord! { x: 0.5, y: 0.5 };
         assert_eq!(line_string.coordinate_position(&midpoint), CoordPos::Inside);
 
-        let vertex = Coordinate { x: 2.0, y: 0.0 };
+        let vertex = coord! { x: 2.0, y: 0.0 };
         assert_eq!(line_string.coordinate_position(&vertex), CoordPos::Inside);
 
-        let end = Coordinate { x: 3.0, y: 0.0 };
+        let end = coord! { x: 3.0, y: 0.0 };
         assert_eq!(line_string.coordinate_position(&end), CoordPos::OnBoundary);
 
-        let outside = Coordinate { x: 3.0, y: 1.0 };
+        let outside = coord! { x: 3.0, y: 1.0 };
         assert_eq!(line_string.coordinate_position(&outside), CoordPos::Outside);
     }
 
@@ -617,16 +617,16 @@ mod test {
         let start = Coordinate::zero();
         assert_eq!(line_string.coordinate_position(&start), CoordPos::Inside);
 
-        let midpoint = Coordinate { x: 0.5, y: 0.5 };
+        let midpoint = coord! { x: 0.5, y: 0.5 };
         assert_eq!(line_string.coordinate_position(&midpoint), CoordPos::Inside);
 
-        let outside = Coordinate { x: 3.0, y: 1.0 };
+        let outside = coord! { x: 3.0, y: 1.0 };
         assert_eq!(line_string.coordinate_position(&outside), CoordPos::Outside);
     }
 
     #[test]
     fn test_boundary_rule() {
-        let multi_line_string = MultiLineString(vec![
+        let multi_line_string = MultiLineString::new(vec![
             // first two lines have same start point but different end point
             line_string![(x: 0.0, y: 0.0), (x: 1.0, y: 1.0)],
             line_string![(x: 0.0, y: 0.0), (x: -1.0, y: -1.0)],
@@ -638,13 +638,13 @@ mod test {
             line_string![(x: 0.0, y: -2.0), (x: -0.5, y: -0.5)],
         ]);
 
-        let outside_of_all = Coordinate { x: 123.0, y: 123.0 };
+        let outside_of_all = coord! { x: 123.0, y: 123.0 };
         assert_eq!(
             multi_line_string.coordinate_position(&outside_of_all),
             CoordPos::Outside
         );
 
-        let end_of_one_line = Coordinate { x: -1.0, y: -1.0 };
+        let end_of_one_line = coord! { x: -1.0, y: -1.0 };
         assert_eq!(
             multi_line_string.coordinate_position(&end_of_one_line),
             CoordPos::OnBoundary
@@ -658,14 +658,14 @@ mod test {
         );
 
         // *in* the first line, on the boundary of the third line
-        let one_end_plus_midpoint = Coordinate { x: 0.5, y: 0.5 };
+        let one_end_plus_midpoint = coord! { x: 0.5, y: 0.5 };
         assert_eq!(
             multi_line_string.coordinate_position(&one_end_plus_midpoint),
             CoordPos::OnBoundary
         );
 
         // *in* the first line, on the *boundary* of the fourth and fifth line
-        let two_ends_plus_midpoint = Coordinate { x: -0.5, y: -0.5 };
+        let two_ends_plus_midpoint = coord! { x: -0.5, y: -0.5 };
         assert_eq!(
             multi_line_string.coordinate_position(&two_ends_plus_midpoint),
             CoordPos::Inside
@@ -676,63 +676,63 @@ mod test {
     fn test_rect() {
         let rect = Rect::new((0.0, 0.0), (10.0, 10.0));
         assert_eq!(
-            rect.coordinate_position(&Coordinate { x: 5.0, y: 5.0 }),
+            rect.coordinate_position(&coord! { x: 5.0, y: 5.0 }),
             CoordPos::Inside
         );
         assert_eq!(
-            rect.coordinate_position(&Coordinate { x: 0.0, y: 5.0 }),
+            rect.coordinate_position(&coord! { x: 0.0, y: 5.0 }),
             CoordPos::OnBoundary
         );
         assert_eq!(
-            rect.coordinate_position(&Coordinate { x: 15.0, y: 15.0 }),
+            rect.coordinate_position(&coord! { x: 15.0, y: 15.0 }),
             CoordPos::Outside
         );
     }
 
     #[test]
     fn test_triangle() {
-        let triangle = Triangle((0.0, 0.0).into(), (5.0, 10.0).into(), (10.0, 0.0).into());
+        let triangle = Triangle::new((0.0, 0.0).into(), (5.0, 10.0).into(), (10.0, 0.0).into());
         assert_eq!(
-            triangle.coordinate_position(&Coordinate { x: 5.0, y: 5.0 }),
+            triangle.coordinate_position(&coord! { x: 5.0, y: 5.0 }),
             CoordPos::Inside
         );
         assert_eq!(
-            triangle.coordinate_position(&Coordinate { x: 2.5, y: 5.0 }),
+            triangle.coordinate_position(&coord! { x: 2.5, y: 5.0 }),
             CoordPos::OnBoundary
         );
         assert_eq!(
-            triangle.coordinate_position(&Coordinate { x: 2.49, y: 5.0 }),
+            triangle.coordinate_position(&coord! { x: 2.49, y: 5.0 }),
             CoordPos::Outside
         );
     }
 
     #[test]
     fn test_collection() {
-        let triangle = Triangle((0.0, 0.0).into(), (5.0, 10.0).into(), (10.0, 0.0).into());
+        let triangle = Triangle::new((0.0, 0.0).into(), (5.0, 10.0).into(), (10.0, 0.0).into());
         let rect = Rect::new((0.0, 0.0), (10.0, 10.0));
-        let collection = GeometryCollection(vec![triangle.into(), rect.into()]);
+        let collection = GeometryCollection::new_from(vec![triangle.into(), rect.into()]);
 
         //  outside of both
         assert_eq!(
-            collection.coordinate_position(&Coordinate { x: 15.0, y: 15.0 }),
+            collection.coordinate_position(&coord! { x: 15.0, y: 15.0 }),
             CoordPos::Outside
         );
 
         // inside both
         assert_eq!(
-            collection.coordinate_position(&Coordinate { x: 5.0, y: 5.0 }),
+            collection.coordinate_position(&coord! { x: 5.0, y: 5.0 }),
             CoordPos::Inside
         );
 
         // inside one, boundary of other
         assert_eq!(
-            collection.coordinate_position(&Coordinate { x: 2.5, y: 5.0 }),
+            collection.coordinate_position(&coord! { x: 2.5, y: 5.0 }),
             CoordPos::OnBoundary
         );
 
         //  boundary of both
         assert_eq!(
-            collection.coordinate_position(&Coordinate { x: 5.0, y: 10.0 }),
+            collection.coordinate_position(&coord! { x: 5.0, y: 10.0 }),
             CoordPos::Outside
         );
     }
