@@ -36,8 +36,8 @@
 //! ```
 
 use crate::{
-    CoordNum, Coordinate, Geometry, GeometryCollection, Line, LineString, MultiLineString,
-    MultiPoint, MultiPolygon, Point, Polygon, Rect, Triangle,
+    coord, CoordNum, Geometry, GeometryCollection, Line, LineString, MultiLineString, MultiPoint,
+    MultiPolygon, Point, Polygon, Rect, Triangle,
 };
 
 /// Map a function over all the coordinates in an object, returning a new one
@@ -165,6 +165,45 @@ pub trait MapCoordsInplace<T> {
         T: CoordNum;
 }
 
+/// Map a fallible function over all the coordinates in a geometry, returning a Result
+pub trait TryMapCoordsInplace<T, E> {
+    /// Map a fallible function over all the coordinates in a geometry, in place, returning a `Result`.
+    ///
+    /// Upon encountering an `Err` from the function, `try_map_coords_inplace` immediately returns
+    /// and the geometry is potentially left in a partially mapped state.
+    ///
+    /// # Examples
+    ///
+    /// ```
+    /// use geo::algorithm::map_coords::TryMapCoordsInplace;
+    ///
+    /// let mut p1 = geo::point!{x: 10u32, y: 20u32};
+    ///
+    /// p1.try_map_coords_inplace(|&(x, y)| -> Result<_, &str> {
+    ///     Ok((
+    ///         x.checked_add(1000).ok_or("Overflow")?,
+    ///         y.checked_mul(2).ok_or("Overflow")?,
+    ///     ))
+    /// })?;
+    ///
+    /// assert_eq!(
+    ///     p1,
+    ///     geo::point!{x: 1010u32, y: 40u32},
+    /// );
+    /// # Ok::<(), &str>(())
+    /// ```
+    fn try_map_coords_inplace(
+        &mut self,
+        func: impl Fn(&(T, T)) -> Result<(T, T), E>,
+    ) -> Result<(), E>
+    where
+        T: CoordNum;
+}
+
+//-----------------------//
+// Point implementations //
+//-----------------------//
+
 impl<T: CoordNum, NT: CoordNum> MapCoords<T, NT> for Point<T> {
     type Output = Point<NT>;
 
@@ -194,6 +233,23 @@ impl<T: CoordNum> MapCoordsInplace<T> for Point<T> {
     }
 }
 
+impl<T: CoordNum, E> TryMapCoordsInplace<T, E> for Point<T> {
+    fn try_map_coords_inplace(
+        &mut self,
+        func: impl Fn(&(T, T)) -> Result<(T, T), E>,
+    ) -> Result<(), E> {
+        let new_point = func(&(self.0.x, self.0.y))?;
+        self.0.x = new_point.0;
+        self.0.y = new_point.1;
+
+        Ok(())
+    }
+}
+
+//----------------------//
+// Line implementations //
+//----------------------//
+
 impl<T: CoordNum, NT: CoordNum> MapCoords<T, NT> for Line<T> {
     type Output = Line<NT>;
 
@@ -231,6 +287,27 @@ impl<T: CoordNum> MapCoordsInplace<T> for Line<T> {
     }
 }
 
+impl<T: CoordNum, E> TryMapCoordsInplace<T, E> for Line<T> {
+    fn try_map_coords_inplace(
+        &mut self,
+        func: impl Fn(&(T, T)) -> Result<(T, T), E>,
+    ) -> Result<(), E> {
+        let new_start = func(&(self.start.x, self.start.y))?;
+        self.start.x = new_start.0;
+        self.start.y = new_start.1;
+
+        let new_end = func(&(self.end.x, self.end.y))?;
+        self.end.x = new_end.0;
+        self.end.y = new_end.1;
+
+        Ok(())
+    }
+}
+
+//----------------------------//
+// LineString implementations //
+//----------------------------//
+
 impl<T: CoordNum, NT: CoordNum> MapCoords<T, NT> for LineString<T> {
     type Output = LineString<NT>;
 
@@ -268,6 +345,24 @@ impl<T: CoordNum> MapCoordsInplace<T> for LineString<T> {
     }
 }
 
+impl<T: CoordNum, E> TryMapCoordsInplace<T, E> for LineString<T> {
+    fn try_map_coords_inplace(
+        &mut self,
+        func: impl Fn(&(T, T)) -> Result<(T, T), E>,
+    ) -> Result<(), E> {
+        for p in &mut self.0 {
+            let new_coords = func(&(p.x, p.y))?;
+            p.x = new_coords.0;
+            p.y = new_coords.1;
+        }
+        Ok(())
+    }
+}
+
+//-------------------------//
+// Polygon implementations //
+//-------------------------//
+
 impl<T: CoordNum, NT: CoordNum> MapCoords<T, NT> for Polygon<T> {
     type Output = Polygon<NT>;
 
@@ -313,11 +408,43 @@ impl<T: CoordNum> MapCoordsInplace<T> for Polygon<T> {
     }
 }
 
+impl<T: CoordNum, E> TryMapCoordsInplace<T, E> for Polygon<T> {
+    fn try_map_coords_inplace(
+        &mut self,
+        func: impl Fn(&(T, T)) -> Result<(T, T), E>,
+    ) -> Result<(), E> {
+        let mut result = Ok(());
+
+        self.exterior_mut(|line_string| {
+            if let Err(e) = line_string.try_map_coords_inplace(&func) {
+                result = Err(e);
+            }
+        });
+
+        if result.is_ok() {
+            self.interiors_mut(|line_strings| {
+                for line_string in line_strings {
+                    if let Err(e) = line_string.try_map_coords_inplace(&func) {
+                        result = Err(e);
+                        break;
+                    }
+                }
+            });
+        }
+
+        result
+    }
+}
+
+//----------------------------//
+// MultiPoint implementations //
+//----------------------------//
+
 impl<T: CoordNum, NT: CoordNum> MapCoords<T, NT> for MultiPoint<T> {
     type Output = MultiPoint<NT>;
 
     fn map_coords(&self, func: impl Fn(&(T, T)) -> (NT, NT) + Copy) -> Self::Output {
-        MultiPoint(self.iter().map(|p| p.map_coords(func)).collect())
+        MultiPoint::new(self.iter().map(|p| p.map_coords(func)).collect())
     }
 }
 
@@ -328,7 +455,7 @@ impl<T: CoordNum, NT: CoordNum, E> TryMapCoords<T, NT, E> for MultiPoint<T> {
         &self,
         func: impl Fn(&(T, T)) -> Result<(NT, NT), E> + Copy,
     ) -> Result<Self::Output, E> {
-        Ok(MultiPoint(
+        Ok(MultiPoint::new(
             self.0
                 .iter()
                 .map(|p| p.try_map_coords(func))
@@ -345,11 +472,27 @@ impl<T: CoordNum> MapCoordsInplace<T> for MultiPoint<T> {
     }
 }
 
+impl<T: CoordNum, E> TryMapCoordsInplace<T, E> for MultiPoint<T> {
+    fn try_map_coords_inplace(
+        &mut self,
+        func: impl Fn(&(T, T)) -> Result<(T, T), E>,
+    ) -> Result<(), E> {
+        for p in &mut self.0 {
+            p.try_map_coords_inplace(&func)?;
+        }
+        Ok(())
+    }
+}
+
+//---------------------------------//
+// MultiLineString implementations //
+//---------------------------------//
+
 impl<T: CoordNum, NT: CoordNum> MapCoords<T, NT> for MultiLineString<T> {
     type Output = MultiLineString<NT>;
 
     fn map_coords(&self, func: impl Fn(&(T, T)) -> (NT, NT) + Copy) -> Self::Output {
-        MultiLineString(self.iter().map(|l| l.map_coords(func)).collect())
+        MultiLineString::new(self.iter().map(|l| l.map_coords(func)).collect())
     }
 }
 
@@ -360,7 +503,7 @@ impl<T: CoordNum, NT: CoordNum, E> TryMapCoords<T, NT, E> for MultiLineString<T>
         &self,
         func: impl Fn(&(T, T)) -> Result<(NT, NT), E> + Copy,
     ) -> Result<Self::Output, E> {
-        Ok(MultiLineString(
+        Ok(MultiLineString::new(
             self.0
                 .iter()
                 .map(|l| l.try_map_coords(func))
@@ -377,11 +520,27 @@ impl<T: CoordNum> MapCoordsInplace<T> for MultiLineString<T> {
     }
 }
 
+impl<T: CoordNum, E> TryMapCoordsInplace<T, E> for MultiLineString<T> {
+    fn try_map_coords_inplace(
+        &mut self,
+        func: impl Fn(&(T, T)) -> Result<(T, T), E>,
+    ) -> Result<(), E> {
+        for p in &mut self.0 {
+            p.try_map_coords_inplace(&func)?;
+        }
+        Ok(())
+    }
+}
+
+//------------------------------//
+// MultiPolygon implementations //
+//------------------------------//
+
 impl<T: CoordNum, NT: CoordNum> MapCoords<T, NT> for MultiPolygon<T> {
     type Output = MultiPolygon<NT>;
 
     fn map_coords(&self, func: impl Fn(&(T, T)) -> (NT, NT) + Copy) -> Self::Output {
-        MultiPolygon(self.iter().map(|p| p.map_coords(func)).collect())
+        MultiPolygon::new(self.iter().map(|p| p.map_coords(func)).collect())
     }
 }
 
@@ -392,7 +551,7 @@ impl<T: CoordNum, NT: CoordNum, E> TryMapCoords<T, NT, E> for MultiPolygon<T> {
         &self,
         func: impl Fn(&(T, T)) -> Result<(NT, NT), E> + Copy,
     ) -> Result<Self::Output, E> {
-        Ok(MultiPolygon(
+        Ok(MultiPolygon::new(
             self.0
                 .iter()
                 .map(|p| p.try_map_coords(func))
@@ -409,6 +568,22 @@ impl<T: CoordNum> MapCoordsInplace<T> for MultiPolygon<T> {
     }
 }
 
+impl<T: CoordNum, E> TryMapCoordsInplace<T, E> for MultiPolygon<T> {
+    fn try_map_coords_inplace(
+        &mut self,
+        func: impl Fn(&(T, T)) -> Result<(T, T), E>,
+    ) -> Result<(), E> {
+        for p in &mut self.0 {
+            p.try_map_coords_inplace(&func)?;
+        }
+        Ok(())
+    }
+}
+
+//--------------------------//
+// Geometry implementations //
+//--------------------------//
+
 impl<T: CoordNum, NT: CoordNum> MapCoords<T, NT> for Geometry<T> {
     type Output = Geometry<NT>;
 
@@ -471,11 +646,35 @@ impl<T: CoordNum> MapCoordsInplace<T> for Geometry<T> {
     }
 }
 
+impl<T: CoordNum, E> TryMapCoordsInplace<T, E> for Geometry<T> {
+    fn try_map_coords_inplace(
+        &mut self,
+        func: impl Fn(&(T, T)) -> Result<(T, T), E>,
+    ) -> Result<(), E> {
+        match *self {
+            Geometry::Point(ref mut x) => x.try_map_coords_inplace(func),
+            Geometry::Line(ref mut x) => x.try_map_coords_inplace(func),
+            Geometry::LineString(ref mut x) => x.try_map_coords_inplace(func),
+            Geometry::Polygon(ref mut x) => x.try_map_coords_inplace(func),
+            Geometry::MultiPoint(ref mut x) => x.try_map_coords_inplace(func),
+            Geometry::MultiLineString(ref mut x) => x.try_map_coords_inplace(func),
+            Geometry::MultiPolygon(ref mut x) => x.try_map_coords_inplace(func),
+            Geometry::GeometryCollection(ref mut x) => x.try_map_coords_inplace(func),
+            Geometry::Rect(ref mut x) => x.try_map_coords_inplace(func),
+            Geometry::Triangle(ref mut x) => x.try_map_coords_inplace(func),
+        }
+    }
+}
+
+//------------------------------------//
+// GeometryCollection implementations //
+//------------------------------------//
+
 impl<T: CoordNum, NT: CoordNum> MapCoords<T, NT> for GeometryCollection<T> {
     type Output = GeometryCollection<NT>;
 
     fn map_coords(&self, func: impl Fn(&(T, T)) -> (NT, NT) + Copy) -> Self::Output {
-        GeometryCollection(self.iter().map(|g| g.map_coords(func)).collect())
+        GeometryCollection::new_from(self.iter().map(|g| g.map_coords(func)).collect())
     }
 }
 
@@ -486,7 +685,7 @@ impl<T: CoordNum, NT: CoordNum, E> TryMapCoords<T, NT, E> for GeometryCollection
         &self,
         func: impl Fn(&(T, T)) -> Result<(NT, NT), E> + Copy,
     ) -> Result<Self::Output, E> {
-        Ok(GeometryCollection(
+        Ok(GeometryCollection::new_from(
             self.0
                 .iter()
                 .map(|g| g.try_map_coords(func))
@@ -503,6 +702,22 @@ impl<T: CoordNum> MapCoordsInplace<T> for GeometryCollection<T> {
     }
 }
 
+impl<T: CoordNum, E> TryMapCoordsInplace<T, E> for GeometryCollection<T> {
+    fn try_map_coords_inplace(
+        &mut self,
+        func: impl Fn(&(T, T)) -> Result<(T, T), E>,
+    ) -> Result<(), E> {
+        for p in &mut self.0 {
+            p.try_map_coords_inplace(&func)?;
+        }
+        Ok(())
+    }
+}
+
+//----------------------//
+// Rect implementations //
+//----------------------//
+
 impl<T: CoordNum, NT: CoordNum> MapCoords<T, NT> for Rect<T> {
     type Output = Rect<NT>;
 
@@ -532,6 +747,21 @@ impl<T: CoordNum> MapCoordsInplace<T> for Rect<T> {
     }
 }
 
+impl<T: CoordNum, E> TryMapCoordsInplace<T, E> for Rect<T> {
+    fn try_map_coords_inplace(
+        &mut self,
+        func: impl Fn(&(T, T)) -> Result<(T, T), E>,
+    ) -> Result<(), E> {
+        let mut new_rect = Rect::new(func(&self.min().x_y())?, func(&self.max().x_y())?);
+        ::std::mem::swap(self, &mut new_rect);
+        Ok(())
+    }
+}
+
+//--------------------------//
+// Triangle implementations //
+//--------------------------//
+
 impl<T: CoordNum, NT: CoordNum> MapCoords<T, NT> for Triangle<T> {
     type Output = Triangle<NT>;
 
@@ -540,10 +770,10 @@ impl<T: CoordNum, NT: CoordNum> MapCoords<T, NT> for Triangle<T> {
         let p2 = func(&self.1.x_y());
         let p3 = func(&self.2.x_y());
 
-        Triangle(
-            Coordinate { x: p1.0, y: p1.1 },
-            Coordinate { x: p2.0, y: p2.1 },
-            Coordinate { x: p3.0, y: p3.1 },
+        Triangle::new(
+            coord! { x: p1.0, y: p1.1 },
+            coord! { x: p2.0, y: p2.1 },
+            coord! { x: p3.0, y: p3.1 },
         )
     }
 }
@@ -559,10 +789,10 @@ impl<T: CoordNum, NT: CoordNum, E> TryMapCoords<T, NT, E> for Triangle<T> {
         let p2 = func(&self.1.x_y())?;
         let p3 = func(&self.2.x_y())?;
 
-        Ok(Triangle(
-            Coordinate { x: p1.0, y: p1.1 },
-            Coordinate { x: p2.0, y: p2.1 },
-            Coordinate { x: p3.0, y: p3.1 },
+        Ok(Triangle::new(
+            coord! { x: p1.0, y: p1.1 },
+            coord! { x: p2.0, y: p2.1 },
+            coord! { x: p3.0, y: p3.1 },
         ))
     }
 }
@@ -573,16 +803,37 @@ impl<T: CoordNum> MapCoordsInplace<T> for Triangle<T> {
         let p2 = func(&self.1.x_y());
         let p3 = func(&self.2.x_y());
 
-        let mut new_triangle = Triangle(
-            Coordinate { x: p1.0, y: p1.1 },
-            Coordinate { x: p2.0, y: p2.1 },
-            Coordinate { x: p3.0, y: p3.1 },
+        let mut new_triangle = Triangle::new(
+            coord! { x: p1.0, y: p1.1 },
+            coord! { x: p2.0, y: p2.1 },
+            coord! { x: p3.0, y: p3.1 },
         );
 
         ::std::mem::swap(self, &mut new_triangle);
     }
 }
 
+impl<T: CoordNum, E> TryMapCoordsInplace<T, E> for Triangle<T> {
+    fn try_map_coords_inplace(
+        &mut self,
+        func: impl Fn(&(T, T)) -> Result<(T, T), E>,
+    ) -> Result<(), E> {
+        let p1 = func(&self.0.x_y())?;
+        let p2 = func(&self.1.x_y())?;
+        let p3 = func(&self.2.x_y())?;
+
+        let mut new_triangle = Triangle::new(
+            coord! { x: p1.0, y: p1.1 },
+            coord! { x: p2.0, y: p2.1 },
+            coord! { x: p3.0, y: p3.1 },
+        );
+
+        ::std::mem::swap(self, &mut new_triangle);
+
+        Ok(())
+    }
+}
+
 #[cfg(test)]
 mod test {
     use super::*;
@@ -608,8 +859,8 @@ mod test {
     fn rect_inplace() {
         let mut rect = Rect::new((10, 10), (20, 20));
         rect.map_coords_inplace(|&(x, y)| (x + 10, y + 20));
-        assert_eq!(rect.min(), Coordinate { x: 20, y: 30 });
-        assert_eq!(rect.max(), Coordinate { x: 30, y: 40 });
+        assert_eq!(rect.min(), coord! { x: 20, y: 30 });
+        assert_eq!(rect.max(), coord! { x: 30, y: 40 });
     }
 
     #[test]
@@ -627,16 +878,16 @@ mod test {
             }
         });
 
-        assert_eq!(rect.min(), Coordinate { x: 1, y: 1 });
-        assert_eq!(rect.max(), Coordinate { x: 4, y: 4 });
+        assert_eq!(rect.min(), coord! { x: 1, y: 1 });
+        assert_eq!(rect.max(), coord! { x: 4, y: 4 });
     }
 
     #[test]
     fn rect_map_coords() {
         let rect = Rect::new((10, 10), (20, 20));
         let another_rect = rect.map_coords(|&(x, y)| (x + 10, y + 20));
-        assert_eq!(another_rect.min(), Coordinate { x: 20, y: 30 });
-        assert_eq!(another_rect.max(), Coordinate { x: 30, y: 40 });
+        assert_eq!(another_rect.min(), coord! { x: 20, y: 30 });
+        assert_eq!(another_rect.max(), coord! { x: 30, y: 40 });
     }
 
     #[test]
@@ -666,8 +917,8 @@ mod test {
             }
         });
         let new_rect = result.unwrap();
-        assert_eq!(new_rect.min(), Coordinate { x: 1, y: 1 });
-        assert_eq!(new_rect.max(), Coordinate { x: 4, y: 4 });
+        assert_eq!(new_rect.min(), coord! { x: 1, y: 1 });
+        assert_eq!(new_rect.max(), coord! { x: 4, y: 4 });
     }
 
     #[test]
@@ -718,11 +969,11 @@ mod test {
     fn multipoint() {
         let p1 = Point::new(10., 10.);
         let p2 = Point::new(0., -100.);
-        let mp = MultiPoint(vec![p1, p2]);
+        let mp = MultiPoint::new(vec![p1, p2]);
 
         assert_eq!(
             mp.map_coords(|&(x, y)| (x + 10., y + 100.)),
-            MultiPoint(vec![Point::new(20., 110.), Point::new(10., 0.)])
+            MultiPoint::new(vec![Point::new(20., 110.), Point::new(10., 0.)])
         );
     }
 
@@ -730,11 +981,11 @@ mod test {
     fn multilinestring() {
         let line1: LineString<f32> = LineString::from(vec![(0., 0.), (1., 2.)]);
         let line2: LineString<f32> = LineString::from(vec![(-1., 0.), (0., 0.), (1., 2.)]);
-        let mline = MultiLineString(vec![line1, line2]);
+        let mline = MultiLineString::new(vec![line1, line2]);
         let mline2 = mline.map_coords(|&(x, y)| (x + 10., y - 100.));
         assert_relative_eq!(
             mline2,
-            MultiLineString(vec![
+            MultiLineString::new(vec![
                 LineString::from(vec![(10., -100.), (11., -98.)]),
                 LineString::from(vec![(9., -100.), (10., -100.), (11., -98.)]),
             ]),
@@ -770,7 +1021,7 @@ mod test {
             ],
         ];
 
-        let mp = MultiPolygon(vec![poly1, poly2]);
+        let mp = MultiPolygon::new(vec![poly1, poly2]);
         let mp2 = mp.map_coords(|&(x, y)| (x * 2., y + 100.));
         assert_eq!(mp2.0.len(), 2);
         assert_relative_eq!(
@@ -811,11 +1062,11 @@ mod test {
         let p1 = Geometry::Point(Point::new(10., 10.));
         let line1 = Geometry::LineString(LineString::from(vec![(0., 0.), (1., 2.)]));
 
-        let gc = GeometryCollection(vec![p1, line1]);
+        let gc = GeometryCollection::new_from(vec![p1, line1]);
 
         assert_eq!(
             gc.map_coords(|&(x, y)| (x + 10., y + 100.)),
-            GeometryCollection(vec![
+            GeometryCollection::new_from(vec![
                 Geometry::Point(Point::new(20., 110.)),
                 Geometry::LineString(LineString::from(vec![(10., 100.), (11., 102.)])),
             ])
@@ -836,7 +1087,7 @@ mod test {
         use proj::{Coord, Proj, ProjError};
         let from = "EPSG:4326";
         let to = "EPSG:2230";
-        let to_feet = Proj::new_known_crs(&from, &to, None).unwrap();
+        let to_feet = Proj::new_known_crs(from, to, None).unwrap();
 
         let f = |x: f64, y: f64| -> Result<_, ProjError> {
             let shifted = to_feet.convert((x, y))?;
@@ -889,7 +1140,7 @@ mod test {
 
     #[test]
     fn rect_map_invert_coords() {
-        let rect = Rect::new(Coordinate { x: 0., y: 0. }, Coordinate { x: 1., y: 1. });
+        let rect = Rect::new(coord! { x: 0., y: 0. }, coord! { x: 1., y: 1. });
 
         // This call should not panic even though Rect::new
         // constructor panics if min coords > max coords
