@@ -16,8 +16,8 @@ where
 {
     let poly1_extremes = poly1.extremes().unwrap();
     let poly2_extremes = poly2.extremes().unwrap();
-    let ymin1 = Point(poly1.exterior().0[poly1_extremes.y_min.index]);
-    let ymax2 = Point(poly2.exterior().0[poly2_extremes.y_max.index]);
+    let ymin1 = Point::from(poly1.exterior().0[poly1_extremes.y_min.index]);
+    let ymax2 = Point::from(poly2.exterior().0[poly2_extremes.y_max.index]);
 
     let mut state = Polydist {
         poly1,
@@ -129,7 +129,7 @@ where
     let mut sin;
     let pnext = poly.exterior().0[next_vertex(poly, idx)];
     let pprev = poly.exterior().0[prev_vertex(poly, idx)];
-    let clockwise = Point(pprev).cross_prod(Point(p.0), Point(pnext)) < T::zero();
+    let clockwise = Point::from(pprev).cross_prod(Point::from(p.0), Point::from(pnext)) < T::zero();
     let slope_prev;
     let slope_next;
     // Slope isn't 0, things are complicated
@@ -323,7 +323,7 @@ where
     let hundred = T::from(100).unwrap();
     let pnext = poly.exterior().0[next_vertex(poly, idx)];
     let pprev = poly.exterior().0[prev_vertex(poly, idx)];
-    let clockwise = Point(pprev).cross_prod(Point(p.0), Point(pnext)) < T::zero();
+    let clockwise = Point::from(pprev).cross_prod(Point::from(p.0), Point::from(pnext)) < T::zero();
     let punit;
     if !vertical {
         punit = unitvector(m, poly, p, idx);
@@ -360,8 +360,8 @@ where
         // implies p.x() < pprev.x()
         punit = Point::new(p.x(), p.y() - hundred);
     }
-    let triarea = Triangle::from([p, punit, Point(pnext)]).signed_area();
-    let edgelen = p.euclidean_distance(&Point(pnext));
+    let triarea = Triangle::from([p, punit, Point::from(pnext)]).signed_area();
+    let edgelen = p.euclidean_distance(&Point::from(pnext));
     let mut sine = triarea / (T::from(0.5).unwrap() * T::from(100).unwrap() * edgelen);
     if sine < -T::one() || sine > T::one() {
         sine = T::one();
@@ -369,7 +369,7 @@ where
     let angle;
     let perpunit = unitpvector(p, punit);
     let mut obtuse = false;
-    let left = leftturn(p, perpunit, Point(pnext));
+    let left = leftturn(p, perpunit, Point::from(pnext));
     if left == 0 {
         obtuse = true;
     }
@@ -453,14 +453,14 @@ where
     if (state.ap1 - minangle).abs() < T::from(0.002).unwrap() {
         state.ip1 = true;
         let p1next = next_vertex(state.poly1, state.p1_idx);
-        state.p1next = Point(state.poly1.exterior().0[p1next]);
+        state.p1next = Point::from(state.poly1.exterior().0[p1next]);
         state.p1_idx = p1next;
         state.alignment = Some(AlignedEdge::VertexP);
     }
     if (state.aq2 - minangle).abs() < T::from(0.002).unwrap() {
         state.iq2 = true;
         let q2next = next_vertex(state.poly2, state.q2_idx);
-        state.q2next = Point(state.poly2.exterior().0[q2next]);
+        state.q2next = Point::from(state.poly2.exterior().0[q2next]);
         state.q2_idx = q2next;
         state.alignment = match state.alignment {
             None => Some(AlignedEdge::VertexQ),
