@@ -82,9 +82,9 @@ pub trait Rotate<T> {
         T: CoordFloat;
 
     #[deprecated(
-        note = "Equivalent to `rotate_around_centroid` except for `Polygon<T>`, 
-                    where it is equivalent to rotating around the polygon's outer ring. 
-                    Call that instead, or `rotate_around_center` if you'd like to rotate 
+        note = "Equivalent to `rotate_around_centroid` except for `Polygon<T>`,
+                    where it is equivalent to rotating around the polygon's outer ring.
+                    Call that instead, or `rotate_around_center` if you'd like to rotate
                     around the geometry's bounding box center."
     )]
     fn rotate(&self, angle: T) -> Self
@@ -358,14 +358,14 @@ mod test {
 
     #[test]
     fn test_rotate_multipoints() {
-        let multi_points = MultiPoint(vec![
+        let multi_points = MultiPoint::new(vec![
             point!(x: 0., y: 0.),
             point!(x: 1., y: 1.),
             point!(x: 2., y: 1.),
         ]);
 
         // Results match shapely for `centroid`
-        let expected_for_centroid = MultiPoint(vec![
+        let expected_for_centroid = MultiPoint::new(vec![
             point!(x: 0.7642977396044841, y: -0.5118446353109125),
             point!(x: 0.7642977396044842, y:  0.9023689270621824),
             point!(x: 1.471404520791032, y:  1.60947570824873),
@@ -376,7 +376,7 @@ mod test {
         );
 
         // Results match shapely for `center`
-        let expected_for_center = MultiPoint(vec![
+        let expected_for_center = MultiPoint::new(vec![
             point!(x: 0.6464466094067262, y: -0.5606601717798212),
             point!(x: 0.6464466094067263, y: 0.8535533905932737),
             point!(x: 1.353553390593274, y: 1.560660171779821),
@@ -584,10 +584,10 @@ mod test {
             (x: 20., y: 20.),
             (x: 40., y: 20.)
         ];
-        let multi_line_string: MultiLineString<f64> = MultiLineString(vec![ls1, ls2]);
+        let multi_line_string: MultiLineString<f64> = MultiLineString::new(vec![ls1, ls2]);
 
         // Results match with Shapely for `centroid`
-        let expected_around_centroid = MultiLineString(vec![
+        let expected_around_centroid = MultiLineString::new(vec![
             line_string![
                 (x: -5.062519283392216, y: 19.72288595632566),
                 (x: -3.648305721019121, y: 19.72288595632566),
@@ -606,7 +606,7 @@ mod test {
         );
 
         // Results match with Shapely for `center`
-        let expected_around_center: MultiLineString<f64> = MultiLineString(vec![
+        let expected_around_center: MultiLineString<f64> = MultiLineString::new(vec![
             line_string![
                 (x: -1.213203435596426, y: 17.07106781186548),
                 (x: 0.2010101267766693, y: 17.07106781186548),
@@ -656,23 +656,23 @@ mod test {
         let expected_centroid: MultiPolygon<f64> = vec![
             polygon![
                 (x: 0., y: 0.),
-                (x: 7.0710678118654755, y: 7.0710678118654746),
-                (x: 0., y: 14.1421356237309510),
-                (x: -7.0710678118654746, y: 7.0710678118654755),
+                (x: 7.0710678118654755, y: 7.071067811865475),
+                (x: 0., y: 14.142135623730951),
+                (x: -7.071067811865475, y: 7.0710678118654755),
                 (x: 0., y: 0.),
             ],
             polygon![
                 (x: 0., y: 0.),
-                (x: -7.0710678118654755, y: -7.0710678118654746),
-                (x: 0., y: -14.1421356237309510),
-                (x: 7.0710678118654746, y: -7.0710678118654755),
+                (x: -7.0710678118654755, y: -7.071067811865475),
+                (x: 0., y: -14.142135623730951),
+                (x: 7.071067811865475, y: -7.0710678118654755),
                 (x: 0., y: 0.),
             ],
         ]
         .into();
 
         // results agree with Shapely / GEOS
-        // (relaxing the episilon a bit)
+        // (relaxing the epsilon a bit)
         assert_relative_eq!(
             multipolygon.rotate_around_centroid(45.),
             expected_centroid,
@@ -727,11 +727,11 @@ mod test {
                 (x: -0.1016007672888048, y: 3.05186627999456),
             ],
             polygon![
-                (x: 8.591731669312811, y: 0.7224948740718733),
+                (x: 8.59173166931281, y: 0.7224948740718733),
                 (x: 10.52358332189095, y: 0.2048567838668318),
                 (x: 13.37059281801868, y: 10.83004087304658),
                 (x: 11.43874116544054, y: 11.34767896325162),
-                (x: 8.591731669312811, y: 0.7224948740718733),
+                (x: 8.59173166931281, y: 0.7224948740718733),
             ],
         ]
         .into();
@@ -757,7 +757,7 @@ mod test {
         assert_eq!(empty_linestring, rotated_empty_linestring);
 
         // multi line string
-        let empty_multilinestring: MultiLineString<f64> = MultiLineString::<f64>(vec![]);
+        let empty_multilinestring: MultiLineString<f64> = MultiLineString::<f64>::new(vec![]);
         let rotated_empty_multilinestring = empty_multilinestring.rotate_around_centroid(90.);
         assert_eq!(empty_multilinestring, rotated_empty_multilinestring);
 
