@@ -154,7 +154,7 @@ where
                 // Out of bounds, i.e. we're on one edge
                 continue;
             }
-            let area = Triangle(
+            let area = Triangle::new(
                 orig.0[ai as usize],
                 orig.0[current_point as usize],
                 orig.0[bi as usize],
@@ -312,16 +312,16 @@ where
         adjacent[smallest.current as usize] = (0, 0);
         counter -= 1;
         // Remove stale segments from R* tree
-        let left_point = Point(orig.0[left as usize]);
-        let middle_point = Point(orig.0[smallest.current]);
-        let right_point = Point(orig.0[right as usize]);
+        let left_point = Point::from(orig.0[left as usize]);
+        let middle_point = Point::from(orig.0[smallest.current]);
+        let right_point = Point::from(orig.0[right as usize]);
 
         let line_1 = Line::new(left_point, middle_point);
         let line_2 = Line::new(middle_point, right_point);
         assert!(tree.remove(&line_1).is_some());
         assert!(tree.remove(&line_2).is_some());
 
-        // Restore continous line segment
+        // Restore continuous line segment
         tree.insert(Line::new(left_point, right_point));
 
         // Now recompute the adjacent triangle(s), using left and right adjacent points
@@ -335,7 +335,7 @@ where
                 // Out of bounds, i.e. we're on one edge
                 continue;
             }
-            let new = Triangle(
+            let new = Triangle::new(
                 orig.0[ai as usize],
                 orig.0[current_point as usize],
                 orig.0[bi as usize],
@@ -394,7 +394,7 @@ where
 {
     let point_a = orig[triangle.left];
     let point_c = orig[triangle.right];
-    let bounding_rect = Triangle(
+    let bounding_rect = Triangle::new(
         orig[triangle.left],
         orig[triangle.current],
         orig[triangle.right],
@@ -410,7 +410,7 @@ where
                 && ca.0 != point_c
                 && cb.0 != point_a
                 && cb.0 != point_c
-                && cartesian_intersect(ca, cb, Point(point_a), Point(point_c))
+                && cartesian_intersect(ca, cb, Point::from(point_a), Point::from(point_c))
         })
 }
 
@@ -576,7 +576,7 @@ where
     T: CoordFloat + RTreeNum,
 {
     fn simplifyvw_preserve(&self, epsilon: &T) -> MultiLineString<T> {
-        MultiLineString(
+        MultiLineString::new(
             self.0
                 .iter()
                 .map(|l| l.simplifyvw_preserve(epsilon))
@@ -606,7 +606,7 @@ where
     T: CoordFloat + RTreeNum,
 {
     fn simplifyvw_preserve(&self, epsilon: &T) -> MultiPolygon<T> {
-        MultiPolygon(
+        MultiPolygon::new(
             self.0
                 .iter()
                 .map(|p| p.simplifyvw_preserve(epsilon))
@@ -638,7 +638,7 @@ where
     T: CoordFloat,
 {
     fn simplifyvw(&self, epsilon: &T) -> MultiLineString<T> {
-        MultiLineString(self.iter().map(|l| l.simplifyvw(epsilon)).collect())
+        MultiLineString::new(self.iter().map(|l| l.simplifyvw(epsilon)).collect())
     }
 }
 
@@ -662,7 +662,7 @@ where
     T: CoordFloat,
 {
     fn simplifyvw(&self, epsilon: &T) -> MultiPolygon<T> {
-        MultiPolygon(self.iter().map(|p| p.simplifyvw(epsilon)).collect())
+        MultiPolygon::new(self.iter().map(|p| p.simplifyvw(epsilon)).collect())
     }
 }
 
@@ -704,13 +704,13 @@ mod test {
         let c = point!(x: 3., y: 3.);
         let d = point!(x: 1., y: 1.);
         // cw + ccw
-        assert_eq!(cartesian_intersect(a, b, c, d), true);
+        assert!(cartesian_intersect(a, b, c, d));
         // ccw + ccw
-        assert_eq!(cartesian_intersect(b, a, c, d), true);
+        assert!(cartesian_intersect(b, a, c, d));
         // cw + cw
-        assert_eq!(cartesian_intersect(a, b, d, c), true);
+        assert!(cartesian_intersect(a, b, d, c));
         // ccw + cw
-        assert_eq!(cartesian_intersect(b, a, d, c), true);
+        assert!(cartesian_intersect(b, a, d, c));
     }
     #[test]
     fn simple_vwp_test() {
@@ -814,7 +814,7 @@ mod test {
             initial_min: 2,
             min_points: 4,
         };
-        let simplified = vwp_wrapper(gt, &points_ls.into(), None, &0.0005);
+        let simplified = vwp_wrapper(gt, &points_ls, None, &0.0005);
         assert_eq!(simplified[0].len(), 3278);
     }
 
@@ -843,12 +843,8 @@ mod test {
     }
     #[test]
     fn visvalingam_test_two_point_linestring() {
-        let mut vec = Vec::new();
-        vec.push(Point::new(0.0, 0.0));
-        vec.push(Point::new(27.8, 0.1));
-        let mut compare = Vec::new();
-        compare.push(Coordinate::from((0.0, 0.0)));
-        compare.push(Coordinate::from((27.8, 0.1)));
+        let vec = vec![Point::new(0.0, 0.0), Point::new(27.8, 0.1)];
+        let compare = vec![Coordinate::from((0.0, 0.0)), Coordinate::from((27.8, 0.1))];
         let simplified = visvalingam(&LineString::from(vec), &1.0);
         assert_eq!(simplified, compare);
     }
@@ -868,10 +864,10 @@ mod test {
         let correct = vec![(5.0, 2.0), (7.0, 25.0), (10.0, 10.0)];
         let correct_ls: Vec<_> = correct.iter().map(|e| Point::new(e.0, e.1)).collect();
 
-        let mline = MultiLineString(vec![LineString::from(points_ls)]);
+        let mline = MultiLineString::new(vec![LineString::from(points_ls)]);
         assert_relative_eq!(
             mline.simplifyvw(&30.),
-            MultiLineString(vec![LineString::from(correct_ls)]),
+            MultiLineString::new(vec![LineString::from(correct_ls)]),
             epsilon = 1e-6
         );
     }
@@ -904,7 +900,7 @@ mod test {
 
     #[test]
     fn multipolygon() {
-        let mpoly = MultiPolygon(vec![Polygon::new(
+        let mpoly = MultiPolygon::new(vec![Polygon::new(
             LineString::from(vec![
                 (0., 0.),
                 (0., 10.),
@@ -920,7 +916,7 @@ mod test {
 
         assert_relative_eq!(
             mpoly2,
-            MultiPolygon(vec![Polygon::new(
+            MultiPolygon::new(vec![Polygon::new(
                 LineString::from(vec![(0., 0.), (0., 10.), (10., 10.), (10., 0.), (0., 0.)]),
                 vec![],
             )]),
